@@ -6,14 +6,14 @@ class HltDoctorTimeTable(BaseModel):
     begin_time = models.DateTimeField(db_column='Begin_Time')
     end_time = models.DateTimeField(db_column='End_Time')
     date = models.DateTimeField(db_column='Date')
-    lpu_doctor = models.ForeignKey('HltLpuDoctor', models.DO_NOTHING, '+', db_column='rf_LPUDoctorID')
+    lpu_doctor = models.ForeignKey('HltLpuDoctor', db_column='rf_LPUDoctorID', **FK_DEFAULT)
     doc_busy_type_id = models.IntegerField(db_column='rf_DocBusyType')
     flag_access = models.IntegerField(db_column='FlagAccess')
     flags = models.IntegerField(db_column='FLAGS')
     uguid = models.CharField(db_column='UGUID', max_length=36)
     last_stub_num = models.IntegerField(db_column='LastStubNum')
     plan_ue = models.IntegerField(db_column='PlanUE')
-    doc_prvd = models.ForeignKey('HltDocPrvd', models.DO_NOTHING, '+', db_column='rf_DocPRVDID')
+    doc_prvd = models.ForeignKey('HltDocPrvd', db_column='rf_DocPRVDID', **FK_DEFAULT)
     healing_room_id = models.IntegerField(db_column='rf_HealingRoomID')
     tt_source = models.IntegerField(db_column='TTSource')
     used_ue = models.IntegerField(db_column='UsedUE')
