@@ -22,8 +22,8 @@ class HltMkab(BaseModel):
     date_bd = models.DateTimeField(db_column='DATE_BD')
     address = models.CharField(db_column='ADRES', max_length=200)
     inv = models.IntegerField(db_column='rf_INVID')
-    smo = models.ForeignKey('OmsSmo', models.DO_NOTHING, related_name='+', db_column='rf_SMOID')
-    other_smo = models.ForeignKey('OmsSmo', models.DO_NOTHING, related_name='+', db_column='rf_OtherSMOID')
+    smo = models.ForeignKey('OmsSmo', db_column='rf_SMOID', **FK_DEFAULT)
+    other_smo = models.ForeignKey('OmsSmo', db_column='rf_OtherSMOID', **FK_DEFAULT)
     phone_work = models.CharField(db_column='PhoneWork', max_length=20)
     phone_home = models.CharField(db_column='PhoneHome', max_length=20)
     work = models.CharField(db_column='Work', max_length=200)
@@ -41,7 +41,7 @@ class HltMkab(BaseModel):
     type_doc = models.ForeignKey('OmsTypedoc', models.DO_NOTHING, db_column='rf_TYPEDOCID')
     s_doc = models.CharField(db_column='S_DOC', max_length=10)
     n_doc = models.CharField(db_column='N_DOC', max_length=15)
-    tip_oms = models.ForeignKey('OmsKlTipOms', models.DO_NOTHING, related_name='+', db_column='rf_kl_TipOMSID')
+    tip_oms = models.ForeignKey('OmsKlTipOms', db_column='rf_kl_TipOMSID', **FK_DEFAULT)
     s_pol = models.CharField(db_column='S_POL', max_length=50)
     n_pol = models.CharField(db_column='N_POL', max_length=50)
     is_worker = models.BooleanField(db_column='IsWorker')
@@ -58,12 +58,12 @@ class HltMkab(BaseModel):
     date_close = models.DateTimeField(db_column='DateClose')
     privilege_category = models.IntegerField(db_column='rf_kl_PrivilegeCategoryID')
     oms_okved = models.ForeignKey('OmsOkved', models.DO_NOTHING, db_column='rf_omsOKVEDID')
-    soc_status = models.ForeignKey('OmsKlSocStatus', models.DO_NOTHING, related_name='+', db_column='rf_kl_SocStatusID')
+    soc_status = models.ForeignKey('OmsKlSocStatus', db_column='rf_kl_SocStatusID', **FK_DEFAULT)
     sex = models.IntegerField(db_column='rf_kl_SexID')
     health_group = models.IntegerField(db_column='rf_kl_HealthGroupID')
-    address_live = models.ForeignKey('KlaAddress', models.DO_NOTHING, related_name='+', db_column='rf_AddressLiveID')
-    address_reg = models.ForeignKey('KlaAddress', models.DO_NOTHING, related_name='+', db_column='rf_AddressRegID')
-    address_work = models.ForeignKey('KlaAddress', models.DO_NOTHING, related_name='+', db_column='rf_AddressWorkID')
+    address_live = models.ForeignKey('KlaAddress', db_column='rf_AddressLiveID', **FK_DEFAULT)
+    address_reg = models.ForeignKey('KlaAddress', db_column='rf_AddressRegID', **FK_DEFAULT)
+    address_work = models.ForeignKey('KlaAddress', db_column='rf_AddressWorkID', **FK_DEFAULT)
     confirm_agree = models.BooleanField(db_column='ConfirmAgree')
     confirm_date = models.DateTimeField(db_column='ConfirmDate')
     confirm_user_fio = models.CharField(db_column='ConfirmUserFIO', max_length=50)
@@ -72,9 +72,9 @@ class HltMkab(BaseModel):
     contact_mphone = models.CharField(db_column='contactMPhone', max_length=25)
     create_username = models.CharField(db_column='CreateUserName', max_length=255)
     edit_username = models.CharField(db_column='EditUserName', max_length=255)
-    confirm_user = models.ForeignKey('XUser', models.DO_NOTHING, related_name='+', db_column='rf_ConfirmUserID')
-    create_user = models.ForeignKey('XUser', models.DO_NOTHING, related_name='+', db_column='rf_CreateUserID')
-    edit_user = models.ForeignKey('XUser', models.DO_NOTHING, related_name='+', db_column='rf_EditUserID')
+    confirm_user = models.ForeignKey('XUser', db_column='rf_ConfirmUserID', **FK_DEFAULT)
+    create_user = models.ForeignKey('XUser', db_column='rf_CreateUserID', **FK_DEFAULT)
+    edit_user = models.ForeignKey('XUser', db_column='rf_EditUserID', **FK_DEFAULT)
     hash0 = models.CharField(db_column='Hash0', max_length=65)
     hash1 = models.CharField(db_column='Hash1', max_length=65)
     hash2 = models.CharField(db_column='Hash2', max_length=65)
