@@ -5,9 +5,9 @@ class HltTypeCallDoctor(BaseModel):
     id = models.AutoField(db_column='TypeCallDoctorID', primary_key=True)
     code = models.CharField(db_column='CODE', max_length=1)
     name = models.CharField(db_column='NAME', max_length=20)
-    datebegin = models.DateTimeField(db_column='DateBegin')
-    dateend = models.DateTimeField(db_column='DateEnd')
-    enumname = models.CharField(db_column='EnumName', max_length=50)
+    date_begin = models.DateTimeField(db_column='DateBegin')
+    date_end = models.DateTimeField(db_column='DateEnd')
+    enum_name = models.CharField(db_column='EnumName', max_length=50)
     flags = models.IntegerField(db_column='Flags')
 
     class Meta:
