@@ -9,11 +9,11 @@ class OmsKlVisitResult(BaseModel):
     name = models.CharField(db_column='NAME', max_length=255)
     date_b = models.DateTimeField(db_column='Date_B')
     date_e = models.DateTimeField(db_column='Date_E')
-    department_type = models.ForeignKey('OmsKlDepartmentType', models.DO_NOTHING, '+', db_column='rf_kl_DepartmentTypeID')
+    department_type = models.ForeignKey('OmsKlDepartmentType', db_column='rf_kl_DepartmentTypeID', **FK_DEFAULT)
     code_dd = models.CharField(db_column='CODE_DD', max_length=50)
     code_region = models.CharField(db_column='CODE_Region', max_length=50)
     code_federal = models.CharField(db_column='CODE_Federal', max_length=50)
-    dd_service = models.ForeignKey('OmsKlDDService', models.DO_NOTHING, '+', db_column='rf_kl_DDServiceID')
+    dd_service = models.ForeignKey('OmsKlDDService', db_column='rf_kl_DDServiceID', **FK_DEFAULT)
 
     class Meta:
         managed = False
