@@ -9,12 +9,12 @@ class OmsPrvs(models.Model):
     i_prvs = models.IntegerField(db_column='I_PRVS')
     date_beg = models.DateTimeField(db_column='Date_Beg')
     date_end = models.DateTimeField(db_column='Date_End')
-    main_prvs = models.ForeignKey('self', models.DO_NOTHING, '+', db_column='rf_MainPRVSID')
-    prvs = models.ForeignKey('self', models.DO_NOTHING, '+', db_column='rf_PRVSID')
+    main_prvs = models.ForeignKey('self', db_column='rf_MainPRVSID', **FK_DEFAULT)
+    prvs = models.ForeignKey('self', db_column='rf_PRVSID', **FK_DEFAULT)
     id_post_mz = models.CharField(db_column='IDPost_MZ', max_length=50)
     post_name = models.CharField(db_column='PostName', max_length=150)
-    profit_type = models.ForeignKey('OmsKlProfitType', models.DO_NOTHING, '+', db_column='rf_kl_ProfitTypeID')
-    prvd = models.ForeignKey('OmsPrvd', models.DO_NOTHING, '+', db_column='rf_PRVDID')
+    profit_type = models.ForeignKey('OmsKlProfitType', db_column='rf_kl_ProfitTypeID', **FK_DEFAULT)
+    prvd = models.ForeignKey('OmsPrvd', db_column='rf_PRVDID', **FK_DEFAULT)
 
     class Meta:
         managed = False
